@@ -1,5 +1,5 @@
 import requests
-
+import json
 class Client():
 	"""
 	Client endpoint to handle the api requests
@@ -11,20 +11,22 @@ class Client():
 
 	def request(self, type, resource, payload=None):
 		try:
-			headers = {'loaderio-auth': self.api_key}
+			headers = {'loaderio-auth': self.api_key, 'Content-Type' : 'application/json'}
 			if type is 'GET':			
 				response = requests.get(self.url+resource, headers = headers)
 			elif type is 'POST':
-				response = requests.post(self.url+resource, data=payload, headers = headers)
+				response = requests.post(self.url+resource, data=json.dumps(payload), headers = headers)
 			elif type is 'PUT':
-				response = requests.put(self.url+resource, data=payload, headers = headers)
+				response = requests.put(self.url+resource, data=json.dumps(payload), headers = headers)
 			else:
 				response = requests.delete(self.url+resource, headers = headers)
 			
 			if response is not None:
+				print response.text
 				return response.json()
 					
 		except Exception, e:
+			print e;
 			pass
 		finally:
 			pass
\ No newline at end of file
